@@ -201,7 +201,7 @@ use autocxx_engine::IncludeCppEngine;
 ///
 /// * *Recommended*: provide various [`generate`] directives in the
 ///   [`include_cpp`] macro. This can specify functions or types.
-/// * *Not recommended*: in your `build.rs`, call `Builder::auto_allowlist`.
+/// * *Not recommended*: in your `build.rs`, call [`Builder::auto_allowlist`].
 ///   This will attempt to spot _uses_ of FFI bindings anywhere in your Rust code
 ///   and build the allowlist that way. This is experimental and has known limitations.
 /// * *Strongly not recommended*: use [`generate_all`]. This will attempt to
@@ -484,7 +484,7 @@ use autocxx_engine::IncludeCppEngine;
 /// * [S2 example](https://github.com/google/autocxx/tree/main/examples/s2) - example using S2 geometry library
 /// * [Steam example](https://github.com/google/autocxx/tree/main/examples/steam-mini) - example using (something like) the Steam client library
 /// * [Subclass example](https://github.com/google/autocxx/tree/main/examples/subclass) - example using subclasses
-/// * [Integration tests](https://github.com/google/autocxx/blob/main/engine/src/integration_tests.rs)
+/// * [Integration tests](https://github.com/google/autocxx/blob/main/integration-tests/src/tests.rs)
 ///   - hundreds of small snippets
 ///
 /// Contributions of more examples to the `examples` directory are much appreciated!
@@ -638,22 +638,20 @@ macro_rules! exclude_impls {
     ($($tt:tt)*) => { $crate::usage!{$($tt)*} };
 }
 
-/// Declare that a given type is a Rust type. These may be used within
-/// references in the signatures of C++ functions, for instance.
-/// This will contribute to an `extern "Rust"` section of the generated
-/// `cxx` bindings.
+/// Deprecated - use [`extern_rust_type`] instead.
 #[macro_export]
+#[deprecated]
 macro_rules! rust_type {
     ($($tt:tt)*) => { $crate::usage!{$($tt)*} };
 }
 
-/// Declare a Rust subclass of a C++ class.
-/// A directive to be included inside
-/// [include_cpp] - see [include_cpp] for general information.
-/// Use this in conjunction with [`subclass::is_subclass`].
-/// See [`subclass::CppSubclass`] for information about the
-/// multiple steps you need to take to be able to make Rust
-/// subclasses of a C++ class.
+/// See [`extern_rust::extern_rust_type`].
+#[macro_export]
+macro_rules! extern_rust_type {
+    ($($tt:tt)*) => { $crate::usage!{$($tt)*} };
+}
+
+/// See [`subclass::subclass`].
 #[macro_export]
 macro_rules! subclass {
     ($($tt:tt)*) => { $crate::usage!{$($tt)*} };
@@ -727,3 +725,46 @@ pub struct BindingGenerationFailure {
     _unallocatable: [*const u8; 0],
     _pinned: core::marker::PhantomData<core::marker::PhantomPinned>,
 }
+
+/// Tools to export Rust code to C++.
+// These are in a mod to avoid shadowing the definitions of the
+// directives above, which, being macro_rules, are unavoidably
+// in the crate root but must be function-style macros to keep
+// the include_cpp impl happy.
+pub mod extern_rust {
+
+    /// Declare that this is a Rust type which is to be exported to C++.
+    /// You can use this in two ways:
+    /// * as an attribute macro on a Rust type, for instance:
+    ///   ```
+    ///   # use autocxx_macro::extern_rust_type as extern_rust_type;
+    ///   #[extern_rust_type]
+    ///   struct Bar;
+    ///   ```
+    /// * as a directive within the [include_cpp] macro, in which case
+    ///   provide the type path in brackets:
+    ///   ```
+    ///   # use autocxx_macro::include_cpp_impl as include_cpp;
+    ///   include_cpp!(
+    ///   #   parse_only!()
+    ///       #include "input.h"
+    ///       extern_rust_type!(Bar)
+    ///       safety!(unsafe)
+    ///   );
+    ///   struct Bar;
+    ///   ```
+    /// These may be used within references in the signatures of C++ functions,
+    /// for instance. This will contribute to an `extern "Rust"` section of the
+    /// generated `cxx` bindings, and this type will appear in the C++ header
+    /// generated for use in C++.
+    pub use autocxx_macro::extern_rust_type;
+
+    /// Declare that a given function is a Rust function which is to be exported
+    /// to C++. This is used as an attribute macro on a Rust function, for instance:
+    /// ```
+    /// # use autocxx_macro::extern_rust_function as extern_rust_function;
+    /// #[extern_rust_function]
+    /// pub fn call_me_from_cpp() { }
+    /// ```
+    pub use autocxx_macro::extern_rust_function;
+}
